/***********************************************************************************
Note to User: The purpose of this program is to provide sample Stata code for running
weighted frequencies and means for the FMLA 2018 Employee Survey, as well as for testing
for differences across subgroups, using employee weights.

Before running this program, please update the file path in the cd statement.
The file path in this statement should refer to the location on your computer where 
the FMLA 2018 Employee Public Use File dataset (FMLA_2018_Employee_PUF.dta) is saved.

Finally, the public use file documentation included examples using a hypothetical 
indicator variable called male that could be created from the existing gender_cat 
variable. By contrast, the examples below include only variables that appear in the 
FMLA 2018 Employee Public Use File dataset.
***********************************************************************************/

cd "INSERT FILE PATH HERE"
use "FMLA_2018_Employee_PUF.dta"

/*************************************************************************
Run weighted frequencies and means for FMLA 2018 Employee Survey 
*************************************************************************/

svyset [pw=combo_trimmed_weight], vce(bootstrap) bsrw(cmb_bsrw*) mse

/*Run weighted frequencies of FMLA eligibility on full sample*/
svy: tab fmla_eligible

/*Run weighted frequencies of FMLA eligibility on subsample of workers who earn less than $15 per hour*/
svy, subpop(if low_wage==1) : tab fmla_eligible 

/*Test whether percentage of employees earning less than $15 per hour differs by FMLA eligibility*/
svy: reg low_wage i.fmla_eligible 

